from setuptools import setup, find_packages


setup(
    name='jdeppy',
    version='1.0',
    description='Python wrapper for J.DepP',
    url='https://github.com/matsurihime/jdeppy',
    author='matsurihime',
    author_email='pipikapur@gmail.com',
    license='MIT',
    keywords='jdepp',
    # packages=find_packages(),
    classifiers=[
        'Natural Language :: Japanese',
    ],
)
